==> localnews-base-model-1.3.0.2-sources.jar: com/bxm/localnews/common/vo/AppVersion.java <==
package com.bxm.localnews.common.vo;

import java.util.Date;

public class AppVersion {

    private Integer id;

    private Integer mobileType;

    private String version;

    private String content;

    private String downloadLink;

    private Byte isForce;

    private Byte status;

    private Date createtime;

    public Integer getId() {
        return this.id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getMobileType() {
        return this.mobileType;
    }

    public void setMobileType(Integer mobileType) {
        this.mobileType = mobileType;
    }

    public String getVersion() {
        return this.version;
    }

    public void setVersion(String version) {
        this.version = version == null ? null : version.trim();
    }

    public String getContent() {
        return this.content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public String getDownloadLink() {
        return downloadLink;
    }

    public void setDownloadLink(String downloadLink) {
        this.downloadLink = downloadLink;
    }

    public Byte getIsForce() {
        return isForce;
    }

    public void setIsForce(Byte isForce) {
        this.isForce = isForce;
    }

    public Byte getStatus() {
        return this.status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public Date getCreatetime() {
        return this.createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

}

==> localnews-base-model-2.0.1-20190414.113554-1-sources.jar: com/bxm/localnews/common/vo/AppVersion.java <==
package com.bxm.localnews.common.vo;

import java.util.Date;

public class AppVersion {

    private Integer id;

    private Integer mobileType;

    private String title;

    private String version;

    private String content;

    private String downloadLink;

    private Byte isForce;

    private Byte status;

    private Byte enable;

    private Date createtime;

    public Integer getId() {
        return this.id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getMobileType() {
        return this.mobileType;
    }

    public void setMobileType(Integer mobileType) {
        this.mobileType = mobileType;
    }

    public String getVersion() {
        return this.version;
    }

    public void setVersion(String version) {
        this.version = version == null ? null : version.trim();
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return this.content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public String getDownloadLink() {
        return downloadLink;
    }

    public void setDownloadLink(String downloadLink) {
        this.downloadLink = downloadLink;
    }

    public Byte getIsForce() {
        return isForce;
    }

    public void setIsForce(Byte isForce) {
        this.isForce = isForce;
    }

    public Byte getStatus() {
        return this.status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public Byte getEnable() {
        return enable;
    }

    public void setEnable(Byte enable) {
        this.enable = enable;
    }

    public Date getCreatetime() {
        return this.createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

}
